@@ -6,7 +6,7 @@ class DefaultArticleSettings(object):
 
     IS_ARTICLE_TYPE_ENABLED = defaults.IS_ARTICLE_TYPE_ENABLED
     IS_ARTICLE_HITCOUNT_ENABLED = defaults.IS_ARTICLE_HITCOUNT_ENABLED
-    IS_ARTICLE_COMMENTS_ENABLED = defaults.IS_ARTICLE_COMMENTS_ENABLED
+    ARE_COMMENTS_ENABLED = defaults.ARE_COMMENTS_ENABLED
 
     @property
     def INSTALLED_APPS(self):
@@ -15,7 +15,7 @@ class DefaultArticleSettings(object):
         if self.IS_ARTICLE_HITCOUNT_ENABLED and 'hitcount' not in apps:
             apps += ['hitcount']
 
-        if self.IS_ARTICLE_COMMENTS_ENABLED and 'comments' not in apps:
+        if self.ARE_COMMENTS_ENABLED and 'comments' not in apps:
             apps += ['comments']
 
-        return apps
+        return apps + ['articles']
